@@ -18,7 +18,8 @@ BASE_PATH = Path(__file__).parent
 # TODO copy files to working directory
 class GenerationFilesTest(unittest.TestCase):
     def setUp(self):
-        self.project_dir = BASE_PATH / "tmp" / "generation_files"
+        self.framework = os.getenv('TEST_FRAMEWORK')
+        self.project_dir = BASE_PATH / 'tmp' / self.framework / 'generation_files'
         os.makedirs(self.project_dir)
 
         shutil.copy(BASE_PATH / "fixtures/agentstack.json", self.project_dir / "agentstack.json")
@@ -74,7 +75,7 @@ class GenerationFilesTest(unittest.TestCase):
 
     def test_verify_agentstack_project_invalid(self):
         conf.set_path(BASE_PATH / "missing")
-        with self.assertRaises(SystemExit) as _:
+        with self.assertRaises(Exception) as _:
             verify_agentstack_project()
 
     def test_get_framework(self):
@@ -82,16 +83,17 @@ class GenerationFilesTest(unittest.TestCase):
 
     def test_get_framework_missing(self):
         conf.set_path(BASE_PATH / "missing")
-        with self.assertRaises(SystemExit) as _:
+        with self.assertRaises(Exception) as _:
             get_framework()
 
     def test_read_env(self):
         shutil.copy(BASE_PATH / "fixtures/.env", self.project_dir / ".env")
 
         env = EnvFile()
-        assert env.variables == {"ENV_VAR1": "value1", "ENV_VAR2": "value2"}
+        assert env.variables == {"ENV_VAR1": "value1", "ENV_VAR2": "value2", "ENV_VAR3": "12a34b===="}
         assert env["ENV_VAR1"] == "value1"
         assert env["ENV_VAR2"] == "value2"
+        assert env["ENV_VAR3"] == "12a34b===="
         with self.assertRaises(KeyError) as _:
             env["ENV_VAR100"]
 
@@ -105,7 +107,7 @@ class GenerationFilesTest(unittest.TestCase):
         tmp_data = open(self.project_dir / ".env").read()
         assert (
             tmp_data
-            == """\nENV_VAR1=value1\nENV_VAR2=value_ignored\nENV_VAR2=value2\n#ENV_VAR3=""\nENV_VAR100=value2"""
+            == """\nENV_VAR1=value1\nENV_VAR2=value_ignored\nENV_VAR2=value2\nENV_VAR3 = \"12a34b====\"\n#ENV_VAR4=""\nENV_VAR100=value2"""
         )
     
     def test_write_env_numeric_that_can_be_boolean(self):
@@ -116,20 +118,20 @@ class GenerationFilesTest(unittest.TestCase):
             env.append_if_new("ENV_VAR101", 1)
         
         env = EnvFile()  # re-read the file
-        assert env.variables == {"ENV_VAR1": "value1", "ENV_VAR2": "value2", "ENV_VAR100": "0", "ENV_VAR101": "1"}
+        assert env.variables == {"ENV_VAR1": "value1", "ENV_VAR2": "value2", "ENV_VAR3": "12a34b====", "ENV_VAR100": "0", "ENV_VAR101": "1"}
 
     def test_write_env_commented(self):
         """We should be able to write a commented-out value."""
         shutil.copy(BASE_PATH / "fixtures/.env", self.project_dir / ".env")
 
         with EnvFile() as env:
-            env.append_if_new("ENV_VAR3", "value3")
+            env.append_if_new("ENV_VAR4", "value3")
 
         env = EnvFile()  # re-read the file
-        assert env.variables == {"ENV_VAR1": "value1", "ENV_VAR2": "value2", "ENV_VAR3": "value3"}
+        assert env.variables == {"ENV_VAR1": "value1", "ENV_VAR2": "value2", "ENV_VAR3": "12a34b====", "ENV_VAR4": "value3"}
 
         tmp_file = open(self.project_dir / ".env").read()
         assert (
             tmp_file
-            == """\nENV_VAR1=value1\nENV_VAR2=value_ignored\nENV_VAR2=value2\n#ENV_VAR3=""\nENV_VAR3=value3"""
+            == """\nENV_VAR1=value1\nENV_VAR2=value_ignored\nENV_VAR2=value2\nENV_VAR3 = \"12a34b====\"\n#ENV_VAR4=""\nENV_VAR4=value3"""
         )
